@@ -5,7 +5,7 @@ import numpy as np
 import pandas as pd
 
 from physicalrisk.handler.constants.constants import RESOLUTION, FUTURE_MONTH
-from physicalrisk.handler.AWSdata import aws
+#from physicalrisk.handler.AWSdata import aws
 from physicalrisk.handler.raster_handler.rasterhandler import RasterHandler
 from physicalrisk.handler.printMessageHandler.formatePrint import Formatter
 
